@@ -5,6 +5,13 @@
 library(DHS.rates)
 data("AWIR70")
 data("EMIR70")
+data("ADBR70")
+
+## ---- eval=FALSE---------------------------------------------------------
+#  library(haven)
+#  XXIR70 <- read_dta("C:\\Users\\.............................\\XXIR7HFL.DTA")
+#  XXIR70 <- as.data.frame(XXIR70)
+#  
 
 ## ------------------------------------------------------------------------
 (TFR <- fert(AWIR70,Indicator="tfr"))
@@ -24,3 +31,12 @@ data("EMIR70")
 ## ------------------------------------------------------------------------
 (GFR <- fert(EMIR70,Indicator="gfr", EverMW="YES",AWFact="awfactu", Class="v025"))
 
+## ------------------------------------------------------------------------
+(chmort(ADBR70))
+
+## ------------------------------------------------------------------------
+(chmort(ADBR70,JK="Yes"))
+
+## ------------------------------------------------------------------------
+(chmort(ADBR70,Period = 10))
+
